resolve_project_path

Function resolve_project_path 

pub fn resolve_project_path(explicit: Option<&str>) -> Result<PathBuf>
Resolves the project path to scope memories to.

When explicit is provided it is used directly; otherwise the current working directory is used. The path is then resolved to its git top-level (working directory) when inside a repository, so memories are consistently scoped to the repository root. Trailing separators are trimmed.