pub fn default_model(kind: SummaryProviderKind) -> &'static strExpand description
Returns the default model for the given provider kind.
pub fn default_model(kind: SummaryProviderKind) -> &'static strReturns the default model for the given provider kind.