generate_salt

Function generate_salt 

pub fn generate_salt() -> Vec<u8> 
Generates a random salt for key derivation.

The salt is stored in the ref tree at meta/salt (it is not secret) so other machines derive the same key from the same passphrase.